==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/jsf/src/javax/faces/el/ValueBinding.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package javax.faces.el;

import javax.faces.context.*;

@Deprecated
public abstract class ValueBinding
{
  @Deprecated
  public abstract Object getValue(FacesContext context)
    throws EvaluationException, PropertyNotFoundException;

  @Deprecated
  public abstract void setValue(FacesContext context, Object value)
    throws EvaluationException, PropertyNotFoundException;

  @Deprecated
  public abstract boolean isReadOnly(FacesContext context)
    throws EvaluationException, PropertyNotFoundException;

  @Deprecated
  public abstract Class getType(FacesContext context)
    throws EvaluationException, PropertyNotFoundException;

  @Deprecated
  public String getExpressionString()
  {
    return null;
  }
}

==> resin-4.0.66-src.tar.gz: resin-4.0.66/modules/jsf/src/javax/faces/el/ValueBinding.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package javax.faces.el;

import javax.faces.context.*;

/**
 * @deprecated
 */
public abstract class ValueBinding {
  /**
   * @deprecated
   */
  public abstract Object getValue(FacesContext context)
    throws EvaluationException, PropertyNotFoundException;

  /**
   * @deprecated
   */
  public abstract void setValue(FacesContext context, Object value)
    throws EvaluationException, PropertyNotFoundException;

  /**
   * @deprecated
   */
  public abstract boolean isReadOnly(FacesContext context)
    throws EvaluationException, PropertyNotFoundException;

  /**
   * @deprecated
   */
  public abstract Class getType(FacesContext context)
    throws EvaluationException, PropertyNotFoundException;

  /**
   * @deprecated
   */
  public String getExpressionString()
  {
    return null;
  }
}
